@@ -10,7 +10,7 @@ loadPrev::loadPrev(QWidget *parent) :
 
 }
 
-void loadPrev::init(QStringList args_n,QString core_n,QString rom_n,QList<int> states)
+void loadPrev::init(QStringList args_n,QString core_n,QString rom_n,QList<int>)
 {
 rom=rom_n;
 args=args_n;
