@@ -34,40 +34,47 @@ if (bios_path.right(1)!="/")bios_path+="/";
      }
 
     QDir dir(rom_path);
-         dir.setFilter(QDir::Files);
-         dir.setSorting(QDir::Name);
-         dir.setNameFilters(QStringList()<<"*.bin"<<"*.gba"<<"*.zip");
+    dir.setFilter(QDir::Files);
+    dir.setSorting(QDir::Name);
+    dir.setNameFilters(QStringList()<<"*.bin"<<"*.gba"<<"*.zip");
 
-         QFileInfoList list = dir.entryInfoList();
-         int o=0;
-         for (int i = 0; i < list.size(); ++i) {
-             QFileInfo fileInfo = list.at(i);
-             if (fileInfo.fileName()=="gba_bios.bin")continue;
-             ui->listWidget->addItem(new QListWidgetItem(fileInfo.fileName()));
-             roms.insert(o++,fileInfo.absoluteFilePath());
-         }
+    QFileInfoList list = dir.entryInfoList();
+    int o=0;
+    for (int i = 0; i < list.size(); ++i) {
+        QFileInfo fileInfo = list.at(i);
+        if (fileInfo.fileName()=="gba_bios.bin")continue;
+        ui->listWidget->addItem(new QListWidgetItem(fileInfo.fileName()));
+        roms.insert(o++,fileInfo.absoluteFilePath());
+    }
+    if (roms.count() > 0)
+        ui->listWidget->setCurrentRow(0);
 
-connect (ui->pushButton_2,SIGNAL(clicked()),this,SLOT(rom_config()));
-connect (ui->pushButton,SIGNAL(clicked()),this,SLOT(rom_exec()));
+    connect (ui->pushButton_2,SIGNAL(clicked()),this,SLOT(rom_config()));
+    connect (ui->pushButton,SIGNAL(clicked()),this,SLOT(rom_exec()));
 
 
-this->menuBar()->addAction("Default config",this,SLOT(def_cfg()));
-this->menuBar()->addAction("GUI config",this,SLOT(gui_cfg()));
-this->menuBar()->addAction("Configure keys",this,SLOT(set_keys()));
-this->menuBar()->addAction("Help",this,SLOT(open_help()));
+    this->menuBar()->addAction("Default config",this,SLOT(def_cfg()));
+    this->menuBar()->addAction("GUI config",this,SLOT(gui_cfg()));
+    this->menuBar()->addAction("Configure keys",this,SLOT(set_keys()));
+    this->menuBar()->addAction("Help",this,SLOT(open_help()));
 
-connect(ui->listWidget,SIGNAL(currentRowChanged(int)),this,SLOT(currentRowChanged(int)));
+    connect(ui->listWidget,SIGNAL(currentRowChanged(int)),this,SLOT(currentRowChanged(int)));
 }
 
 void MainWindow::rom_exec(){
-QProcess *myProcess = new QProcess();
-QStringList args=current_config;
-args<<roms.value(ui->listWidget->currentRow());
-qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/gpspm").arg(args.join(" ")).toAscii());
-myProcess->startDetached("/opt/maemo/usr/games/gpspm", args,"/opt/gpspm/");
+    game="";
+    cfg->load_cfg();
+    game=ui->listWidget->currentItem()->text();
+    cfg->load_cfg();
+
+    QProcess *myProcess = new QProcess();
+    QStringList args=current_config;
+    args<<roms.value(ui->listWidget->currentRow());
+    qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/gpspm").arg(args.join(" ")).toAscii());
+    myProcess->startDetached("/opt/maemo/usr/games/gpspm", args,"/opt/gpspm/");
 }
 
-void MainWindow::currentRowChanged ( int currentRow ){
+void MainWindow::currentRowChanged ( int ){
     if (ui->listWidget->currentRow()!=-1){
         game="";
         cfg->load_cfg();
@@ -84,9 +91,10 @@ void MainWindow::set_keys(){
 
 void MainWindow::def_cfg()
 {
-game="";
-cfg->setWindowTitle("Config: default");
-cfg->show();
+    game="";
+    cfg->load_cfg();
+    cfg->setWindowTitle("Config: default");
+    cfg->show();
 }
 
 void MainWindow::gui_cfg()
@@ -130,9 +138,13 @@ MainWindow::~MainWindow()
 
 
 void MainWindow::rom_config(){
-    if (ui->listWidget->currentRow()!=-1){
+    if (ui->listWidget->currentRow() != -1){
+        game="";
+        cfg->load_cfg();
+        game=ui->listWidget->currentItem()->text();
+        cfg->load_cfg();
+
         cfg->setWindowTitle("Config:"+game);
         cfg->show();
-}
-
+    }
 }
