@@ -15,19 +15,20 @@ public slots:
     void load_cfg();
     void save_cfg();
     void createCfg();
+    void frameskipChanged(QString value);
 
 private:
     /*
       gpsp [-breack a][-accel][-screen b][-nosound][-fskip c][-fskip_value d][-fstype e][-sound_buffer f]
     */
 
-    QCheckBox *a;
-    QComboBox *b;
-    QCheckBox *c;
-    QComboBox *d;
-    QSpinBox *e;
-    QComboBox *f;
-    QComboBox *g;
+    QCheckBox *chkAccel;
+    QComboBox *cmbScreen;
+    QCheckBox *chkNoSound;
+    QComboBox *cmbFrameskip;
+    QSpinBox *numFrameskipValue;
+    QComboBox *cmbFsType;
+    QComboBox *cmbSoundBuffer;
 
 protected:
     void hideEvent(QHideEvent *);
